@@ -52,7 +52,7 @@ UMLObject* UMLActor::clone() const
  */
 void UMLActor::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
-    QDomElement actorElement = UMLObject::save("UML:Actor", qDoc);
+    QDomElement actorElement = UMLObject::save(QLatin1String("UML:Actor"), qDoc);
     qElement.appendChild(actorElement);
 }
 
