@@ -41,7 +41,7 @@ namespace Uml
 
     void CmdSetTxt::undo()
     {
-        m_ftw->setName("balbalbalbalbla");
+        m_ftw->setName(QLatin1String("balbalbalbalbla"));
         m_ftw->setTextcmd(m_oldstring);
         uDebug() << "string after undo: " << m_ftw->text()
             << "oldstring: "<< m_oldstring << "newstring: "<< m_newstring;
