@@ -51,7 +51,7 @@ public:
 
     virtual CodeBlockWithComments * getCodeBlockWithComments(const QString &tag, const QString &comment, int indentLevel);
 
-    CodeComment * addOrUpdateTaggedCodeComment(const QString &tag = "", const QString &text = "", int indentationLevel = 0);
+    CodeComment * addOrUpdateTaggedCodeComment(const QString &tag = QString(), const QString &text = QString(), int indentationLevel = 0);
 
     CodeBlockWithComments * addOrUpdateTaggedCodeBlockWithComments
                              (const QString &tag, const QString &text, const QString &ctext,
@@ -63,7 +63,7 @@ public:
      * @return  QString
      * @param   prefix
      */
-    virtual QString getUniqueTag(const QString& prefix = "") = 0;
+    virtual QString getUniqueTag(const QString& prefix = QString()) = 0;
 
     /**
      * Virtual methods that return a new code document objects.
