@@ -57,7 +57,7 @@ QString DCodeClassField::getFieldName()
         if(fieldIsSingleValue()) {
             return roleName;
         } else {
-            return roleName + (roleName.right(1) == "s" ? "es" : "s");
+            return roleName + (roleName.right(1) == QLatin1String("s") ? QLatin1String("es") : QLatin1String("s"));
         }
     }
 }
@@ -71,7 +71,7 @@ QString DCodeClassField::getInitialValue()
             return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
         } else {
             uError() << "parent object is not a UMLAttribute";
-            return "";
+            return QString();
         }
         return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
     }
@@ -80,9 +80,9 @@ QString DCodeClassField::getInitialValue()
         if(fieldIsSingleValue()) {
             // FIX : IF the multiplicity is "1" then we should init a new object here, if its 0 or 1,
             //       then we can just return 'empty' string (minor problem).
-            return QString("");
+            return QString();
         } else {
-            return " new "+DCodeGenerator::getListFieldClassName()+"()";
+            return QLatin1String(" new ") + DCodeGenerator::getListFieldClassName() + QLatin1String("()");
         }
     }
 
