@@ -51,7 +51,7 @@ QString JavaCodeClassField::getFieldName()
         if(fieldIsSingleValue()) {
             return roleName.replace(0, 1, roleName.left(1).toLower());
         } else {
-            return roleName.toLower() + "Vector";
+            return roleName.toLower() + QLatin1String("Vector");
         }
     }
 }
@@ -65,7 +65,7 @@ QString JavaCodeClassField::getInitialValue()
             return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
         } else {
             uError() << "parent object is not a UMLAttribute";
-            return "";
+            return QString();
         }
         return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
     }
@@ -74,9 +74,9 @@ QString JavaCodeClassField::getInitialValue()
         if(fieldIsSingleValue()) {
             // FIX : IF the multiplicity is "1" then we should init a new object here, if its 0 or 1,
             //       then we can just return 'empty' string (minor problem).
-            return QString("");
+            return QString();
         } else {
-            return " new "+JavaCodeGenerator::getListFieldClassName()+"()";
+            return QLatin1String(" new ") + JavaCodeGenerator::getListFieldClassName() + QLatin1String("()");
         }
     }
 }
