@@ -54,7 +54,7 @@ QString RubyCodeClassField::getFieldName()
         if(fieldIsSingleValue()) {
             return roleName.replace(0, 1, roleName.left(1).toLower());
         } else {
-            return roleName.toLower() + "Array";
+            return roleName.toLower() + QLatin1String("Array");
         }
     }
 }
@@ -69,7 +69,7 @@ QString RubyCodeClassField::getInitialValue()
             return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
         } else {
             uError() << "parent object is not a UMLAttribute";
-            return "";
+            return QString();
         }
         return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
     }
@@ -78,9 +78,9 @@ QString RubyCodeClassField::getInitialValue()
         if(fieldIsSingleValue()) {
             // FIX : IF the multiplicity is "1" then we should init a new object here, if it is 0 or 1,
             //       then we can just return 'empty' string (minor problem).
-            return QString("");
+            return QString();
         } else {
-            return RubyCodeGenerator::getListFieldClassName()+".new()";
+            return RubyCodeGenerator::getListFieldClassName() + QLatin1String(".new()");
         }
     }
 
