@@ -81,7 +81,7 @@ protected:
     void appendText(CodeClassFieldDeclarationBlock * db);
     void appendText(TextBlockList * items);
     void appendText(CodeMethodBlock * mb);
-    void appendText(CodeComment * comment, TextBlock * parent, UMLObject * umlObj = 0, const QString & compName = "");
+    void appendText(CodeComment * comment, TextBlock * parent, UMLObject * umlObj = 0, const QString & compName = QString());
     void appendText(CodeBlockWithComments * cb);
 
     void rebuildView(int startCursorPos);
@@ -98,7 +98,7 @@ protected:
 private:
     QString            m_parentDocName;
     CodeDocument *     m_parentDoc;
-    CodeViewerDialog * m_parentDlg;
+    CodeViewerDialog * m_parentDialog;
 
     int m_lastPara;
     int m_lastPos;
@@ -117,7 +117,7 @@ private:
 
     void insertText(const QString & text, TextBlock * parent, bool isEditable = false,
                  const QColor & fgcolor = QColor("black"), const QColor & bgcolor = QColor("white"),
-                 UMLObject * umlobj = 0, const QString & displayName = "", int startLine = -1);
+                 UMLObject * umlobj = 0, const QString & displayName = QString(), int startLine = -1);
 
     void editTextBlock(TextBlock * tBlock, int para);
     void clearText();
@@ -128,7 +128,7 @@ private:
     void updateTextBlockFromText(TextBlock * block);
 
     void initText(CodeDocument * doc);
-    void init(CodeViewerDialog * parentDlg, CodeDocument * parentDoc);
+    void init(CodeViewerDialog * parentDialog, CodeDocument * parentDoc);
 
     void changeTextBlockHighlighting(TextBlock * tb, bool selected);
     void setParagraphBackgroundColor(int position, const QColor& color);
