@@ -35,19 +35,13 @@
 /**
  * Constructor.
  */
-StateDialog::StateDialog(UMLView * pView, StateWidget * pWidget)
-  : DialogBase(pView),
+StateDialog::StateDialog(QWidget * parent, StateWidget * pWidget)
+  : DialogBase(parent),
     m_pActivityPage(0),
     m_pStateWidget(pWidget),
-    m_pView(pView),
     m_bChangesMade(false)
 {
     setCaption(i18n("Properties"));
-    setButtons(Help | Default | Apply | Ok | Cancel);
-    setDefaultButton(Ok);
-    setModal(true);
-    showButtonSeparator(true);
-    setFaceType(KPageDialog::List);
     setupPages();
     connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
     connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
@@ -158,15 +152,15 @@ void StateDialog::setupGeneralPage()
         typeStr = i18nc("choice state in statechart", "Choice");
         break;
     default:
-        typeStr = "???";
+        typeStr = QString::fromLatin1("???");
         break;
     }
-    Dialog_Utils::makeLabeledEditField(m_GenPageWidgets.generalGB, generalLayout, 0,
+    Dialog_Utils::makeLabeledEditField(generalLayout, 0,
                                        m_GenPageWidgets.typeL, i18n("State type:"),
                                        m_GenPageWidgets.typeLE, typeStr);
     m_GenPageWidgets.typeLE->setEnabled(false);
 
-    Dialog_Utils::makeLabeledEditField(m_GenPageWidgets.generalGB, generalLayout, 1,
+    Dialog_Utils::makeLabeledEditField(generalLayout, 1,
                                     m_GenPageWidgets.nameL, i18n("State name:"),
                                     m_GenPageWidgets.nameLE);
 
@@ -182,7 +176,7 @@ void StateDialog::setupGeneralPage()
 
     if (type != StateWidget::Normal) {
         m_GenPageWidgets.nameLE->setEnabled(false);
-        m_GenPageWidgets.nameLE->setText("");
+        m_GenPageWidgets.nameLE->setText(QString());
     } else
         m_GenPageWidgets.nameLE->setText(m_pStateWidget->name());
 }
