@@ -28,8 +28,8 @@ static QStringList mime2KdeFilter(const QStringList &mimeTypes, QString *allExte
             kdeFilter.append(mime->patterns().join(QLatin1String(" ")) + QLatin1Char('|') +
             mime->comment(emptyUrl));
         }
-        else if (mimeType == "image/x-dot") {
-            allExt += "*.dot";
+        else if (mimeType == QString::fromLatin1("image/x-dot")) {
+            allExt += QString::fromLatin1("*.dot");
             kdeFilter.append(QLatin1String("*.dot|Dot Files"));
         }
     }
