@@ -23,7 +23,7 @@
 #include "classifierlistitem.h"
 #include "umlclassifierlistitemlist.h"
 #include "dialog_utils.h"
-#include "parmpropdlg.h"
+#include "parameterpropertiesdialog.h"
 #include "stereotype.h"
 #include "uniqueid.h"
 
@@ -94,7 +94,7 @@ void UMLOperationDialog::setupDialog()
     genLayout->setMargin(margin);
     genLayout->setSpacing(10);
 
-    Dialog_Utils::makeLabeledEditField(m_pGenGB, genLayout, 0,
+    Dialog_Utils::makeLabeledEditField(genLayout, 0,
                                     m_pNameL, i18nc("operation name", "&Name:"),
                                     m_pNameLE, m_operation->name());
 
@@ -291,7 +291,7 @@ void UMLOperationDialog::slotNewParameter()
     QString currentName = m_operation->getUniqueParameterName();
     UMLAttribute* newAttribute = new UMLAttribute(m_operation, currentName, Uml::ID::Reserved);
 
-    QPointer<ParmPropDlg> dlg = new ParmPropDlg(this, m_doc, newAttribute);
+    QPointer<ParameterPropertiesDialog> dlg = new ParameterPropertiesDialog(this, m_doc, newAttribute);
     if (dlg->exec()) {
         pAtt = m_operation->findParm(newAttribute->name());
 
@@ -340,7 +340,7 @@ void UMLOperationDialog::slotParameterProperties()
     UMLAttribute* tempAttribute = static_cast<UMLAttribute*>(pOldAtt->clone()); // create a clone of the parameter
 
     // send the clone to the properties dialog box. it will fill in the new parameters.
-    QPointer<ParmPropDlg> dlg = new ParmPropDlg(this, m_doc, tempAttribute); 
+    QPointer<ParameterPropertiesDialog> dlg = new ParameterPropertiesDialog(this, m_doc, tempAttribute);
     if (dlg->exec()) {
         bool namingConflict = false;
         QString newName = tempAttribute->name();
@@ -519,7 +519,7 @@ void UMLOperationDialog::insertTypesSorted(const QString& type)
     // For example, the Ada generator would interpret the return type
     // "void" as an instruction to generate a procedure instead of a
     // function.
-    types << "void";
+    types << QLatin1String("void");
     // add template parameters
     UMLClassifier *classifier = dynamic_cast<UMLClassifier*>(m_operation->parent());
     if (classifier) {
