@@ -73,11 +73,11 @@ void UMLTemplateDialog::setupDialog()
     valuesLayout->addWidget(m_pTypeCB, 0, 1);
     m_pTypeL->setBuddy(m_pTypeCB);
 
-    Dialog_Utils::makeLabeledEditField(m_pValuesGB, valuesLayout, 1,
+    Dialog_Utils::makeLabeledEditField(valuesLayout, 1,
                                     m_pNameL, i18nc("template name", "&Name:"),
                                     m_pNameLE, m_pTemplate->name());
 
-    Dialog_Utils::makeLabeledEditField(m_pValuesGB, valuesLayout, 2,
+    Dialog_Utils::makeLabeledEditField(valuesLayout, 2,
                                     m_pStereoTypeL, i18n("&Stereotype name:"),
                                     m_pStereoTypeLE, m_pTemplate->stereotype());
 
@@ -102,7 +102,7 @@ void UMLTemplateDialog::insertTypesSorted(const QString& type)
 {
     QStringList types;
     // "class" is the nominal type of template parameter
-    types << "class";
+    types << QLatin1String("class");
     // add the active data types to combo box
     UMLDoc *pDoc = UMLApp::app()->document();
     UMLClassifierList namesList(pDoc->concepts());
