@@ -181,7 +181,10 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
         // Remember packages that we've seen - for avoiding cycles.
         UMLPackageList seenPkgs;
         for (; pkg; pkg = currentObj->umlPackage()) {
-            if (nameWithoutFirstPrefix.isEmpty()) {
+            if (nameWithoutFirstPrefix.isEmpty()
+                && (type == UMLObject::ot_UMLObject ||
+                    type == UMLObject::ot_Folder ||
+                    type == UMLObject::ot_Package || type == pkg->baseType())) {
                 if (caseSensitive) {
                     if (pkg->name() == name)
                         return pkg;
@@ -1537,7 +1540,7 @@ UMLObject::ObjectType convert_LVT_OT(UMLListViewItem::ListViewType lvt)
  * @return  The Icon_Utils::IconType corresponding to the lvt.
  *          Returns it_Home in case no mapping to IconType exists.
  */
-Icon_Utils::IconType convert_LVT_IT(UMLListViewItem::ListViewType lvt)
+Icon_Utils::IconType convert_LVT_IT(UMLListViewItem::ListViewType lvt, UMLObject *o)
 {
     Icon_Utils::IconType icon = Icon_Utils::it_Home;
     switch (lvt) {
@@ -1571,7 +1574,10 @@ Icon_Utils::IconType convert_LVT_IT(UMLListViewItem::ListViewType lvt)
             icon = Icon_Utils::it_UseCase;
             break;
         case UMLListViewItem::lvt_Class:
-            icon = Icon_Utils::it_Class;
+            if (o && o->stereotype() == QLatin1String("class-or-package"))
+                icon = Icon_Utils::it_ClassOrPackage;
+            else
+                icon = Icon_Utils::it_Class;
             break;
         case UMLListViewItem::lvt_Package:
             icon = Icon_Utils::it_Package;
