@@ -41,7 +41,7 @@ using namespace Uml;
 
 /**
  * Creates a new ToolBarStateOther.
- * @param umlView The UMLView to use.
+ * @param umlScene The UMLScene to use.
  */
 ToolBarStateOther::ToolBarStateOther(UMLScene *umlScene)
   : ToolBarStatePool(umlScene)
@@ -141,7 +141,7 @@ bool ToolBarStateOther::newWidget()
             break;
 
         case WorkToolBar::tbb_Text:
-            umlWidget = new FloatingTextWidget(m_pUMLScene, Uml::TextRole::Floating, "");
+            umlWidget = new FloatingTextWidget(m_pUMLScene, Uml::TextRole::Floating, QString());
             break;
 
         // Activity buttons
