@@ -24,7 +24,7 @@
 #include "model_utils.h"
 #include "import_utils.h"
 #include "docwindow.h"
-#include "classpropdlg.h"
+#include "classpropertiesdialog.h"
 #include "cmds.h"
 
 // kde includes
@@ -95,7 +95,7 @@ UMLObject::~UMLObject()
  */
 void UMLObject::init()
 {
-    setObjectName("UMLObject");
+    setObjectName(QLatin1String("UMLObject"));
     m_BaseType = ot_UMLObject;
     m_pUMLPackage = 0;
     m_visibility = Uml::Visibility::Public;
@@ -121,7 +121,7 @@ bool UMLObject::showPropertiesPagedDialog(int page, bool assoc)
     Q_UNUSED(page);
     DocWindow *docwindow = UMLApp::app()->docWindow();
     docwindow->updateDocumentation(false);
-    QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this, assoc);
+    QPointer<ClassPropertiesDialog> dlg = new ClassPropertiesDialog((QWidget*)UMLApp::app(), this, assoc);
     bool modified = false;
     if (dlg->exec()) {
         docwindow->showDocumentation(this, true);
@@ -436,7 +436,7 @@ Visibility::Enum UMLObject::visibility() const
 /**
  * Sets the visibility of the object.
  *
- * @param s   The visibility of the object.
+ * @param visibility  The visibility of the object.
  */
 void UMLObject::setVisibility(Visibility::Enum visibility)
 {
@@ -579,7 +579,7 @@ const UMLStereotype * UMLObject::umlStereotype()
 QString UMLObject::stereotype(bool includeAdornments /* = false */) const
 {
     if (m_pStereotype == NULL)
-        return "";
+        return QString();
     QString name = m_pStereotype->name();
     if (includeAdornments)
         name = QString::fromUtf8("«") + name + QString::fromUtf8("»");
@@ -605,7 +605,7 @@ QString UMLObject::package(const QString& separator, bool includeRoot)
         tempSeparator = UMLApp::app()->activeLanguageScopeSeparator();
     QString fqn = fullyQualifiedName(tempSeparator, includeRoot);
     if (!fqn.contains(tempSeparator))
-        return "";
+        return QString();
     QString scope = fqn.left(fqn.length() - tempSeparator.length() - m_name.length());
     return scope;
 }
@@ -724,14 +724,14 @@ bool UMLObject::resolveRef()
                 m_pStereotype->incrRefCount();
                 m_pSecondary = NULL;
             }
-            m_SecondaryId = "";
+            m_SecondaryId = QString();
             maybeSignalObjectCreated();
             return true;
         }
         if (m_SecondaryFallback.isEmpty()) {
             uDebug() << "object with xmi.id=" << m_SecondaryId << " not found, setting to undef";
             UMLFolder *datatypes = pDoc->datatypeFolder();
-            m_pSecondary = Object_Factory::createUMLObject(ot_Datatype, "undef", datatypes, false);
+            m_pSecondary = Object_Factory::createUMLObject(ot_Datatype, QLatin1String("undef"), datatypes, false);
             return true;
         }
     }
@@ -749,13 +749,13 @@ bool UMLObject::resolveRef()
     // than the xmi.id of the model object of the attribute type.
     m_pSecondary = pDoc->findUMLObject(m_SecondaryId, ot_UMLObject, this);
     if (m_pSecondary) {
-        m_SecondaryId = "";
+        m_SecondaryId = QString();
         maybeSignalObjectCreated();
         return true;
     }
     // Work around Object_Factory::createUMLObject()'s incapability
     // of on-the-fly scope creation:
-    if (m_SecondaryId.contains("::")) {
+    if (m_SecondaryId.contains(QLatin1String("::"))) {
         // TODO: Merge Import_Utils::createUMLObject() into Object_Factory::createUMLObject()
         m_pSecondary = Import_Utils::createUMLObject(ot_UMLObject, m_SecondaryId, m_pUMLPackage);
         if (m_pSecondary) {
@@ -768,7 +768,7 @@ bool UMLObject::resolveRef()
                 uDebug() << "Import_Utils::createUMLObject() returned an existing type for "
                          << m_SecondaryId;
             }
-            m_SecondaryId = "";
+            m_SecondaryId = QString();
             return true;
         }
         uError() << "Import_Utils::createUMLObject() failed to create a new type for "
@@ -779,8 +779,8 @@ bool UMLObject::resolveRef()
     // This is very C++ specific - we rely on  some '*' or
     // '&' to decide it's a ref type. Plus, we don't recognize
     // typedefs of ref types.
-    bool isReferenceType = (m_SecondaryId.contains('*') ||
-                            m_SecondaryId.contains('&'));
+    bool isReferenceType = (m_SecondaryId.contains(QLatin1Char('*')) ||
+                            m_SecondaryId.contains(QLatin1Char('&')));
     ObjectType ot = ot_Class;
     if (isReferenceType) {
         ot = ot_Datatype;
@@ -791,7 +791,7 @@ bool UMLObject::resolveRef()
     m_pSecondary = Object_Factory::createUMLObject(ot, m_SecondaryId, NULL);
     if (m_pSecondary == NULL)
         return false;
-    m_SecondaryId = "";
+    m_SecondaryId = QString();
     maybeSignalObjectCreated();
     //qApp->processEvents();
     return true;
@@ -810,19 +810,19 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
       This creates the QDomElement with which to work.
     */
     QDomElement qElement = qDoc.createElement(tag);
-    qElement.setAttribute("isSpecification", "false");
+    qElement.setAttribute(QLatin1String("isSpecification"), QLatin1String("false"));
     if (m_BaseType != ot_Association &&
         m_BaseType != ot_Role &&
         m_BaseType != ot_Attribute) {
-        qElement.setAttribute("isLeaf", "false");
-        qElement.setAttribute("isRoot", "false");
+        qElement.setAttribute(QLatin1String("isLeaf"), QLatin1String("false"));
+        qElement.setAttribute(QLatin1String("isRoot"), QLatin1String("false"));
         if (m_bAbstract)
-            qElement.setAttribute("isAbstract", "true");
+            qElement.setAttribute(QLatin1String("isAbstract"), QLatin1String("true"));
         else
-            qElement.setAttribute("isAbstract", "false");
+            qElement.setAttribute(QLatin1String("isAbstract"), QLatin1String("false"));
     }
-    qElement.setAttribute("xmi.id", Uml::ID::toString(m_nId));
-    qElement.setAttribute("name", m_name);
+    qElement.setAttribute(QLatin1String("xmi.id"), Uml::ID::toString(m_nId));
+    qElement.setAttribute(QLatin1String("name"), m_name);
     if (m_BaseType != ot_Operation &&
         m_BaseType != ot_Role &&
         m_BaseType != ot_Attribute) {
@@ -831,20 +831,20 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
             nmSpc = m_pUMLPackage->id();
         else
             nmSpc = UMLApp::app()->document()->modelID();
-        qElement.setAttribute("namespace", Uml::ID::toString(nmSpc));
+        qElement.setAttribute(QLatin1String("namespace"), Uml::ID::toString(nmSpc));
     }
     if (! m_Doc.isEmpty())
-        qElement.setAttribute("comment", m_Doc);    //CHECK: uml13.dtd compliance
+        qElement.setAttribute(QLatin1String("comment"), m_Doc);    //CHECK: uml13.dtd compliance
 #ifdef XMI_FLAT_PACKAGES
     if (m_pUMLPackage)             //FIXME: uml13.dtd compliance
-        qElement.setAttribute("package", m_pUMLPackage->ID());
+        qElement.setAttribute(QLatin1String("package"), m_pUMLPackage->ID());
 #endif
     QString visibility = Uml::Visibility::toString(m_visibility, false);
-    qElement.setAttribute("visibility", visibility);
+    qElement.setAttribute(QLatin1String("visibility"), visibility);
     if (m_pStereotype != NULL)
-        qElement.setAttribute("stereotype", Uml::ID::toString(m_pStereotype->id()));
+        qElement.setAttribute(QLatin1String("stereotype"), Uml::ID::toString(m_pStereotype->id()));
     if (m_bStatic)
-        qElement.setAttribute("ownerScope", "classifier");
+        qElement.setAttribute(QLatin1String("ownerScope"), QLatin1String("classifier"));
     /* else
         qElement.setAttribute("ownerScope", "instance");
      *** ownerScope defaults to instance if not set **********/
@@ -873,9 +873,9 @@ bool UMLObject::load(QDomElement&)
 bool UMLObject::loadStereotype(QDomElement & element)
 {
     QString tag = element.tagName();
-    if (!UMLDoc::tagEq(tag, "stereotype"))
+    if (!UMLDoc::tagEq(tag, QLatin1String("stereotype")))
         return false;
-    QString stereo = element.attribute("xmi.value", "");
+    QString stereo = element.attribute(QLatin1String("xmi.value"));
     if (stereo.isEmpty() && element.hasChildNodes()) {
         /* like so:
          <UML:ModelElement.stereotype>
@@ -885,8 +885,8 @@ bool UMLObject::loadStereotype(QDomElement & element)
         QDomNode stereoNode = element.firstChild();
         QDomElement stereoElem = stereoNode.toElement();
         tag = stereoElem.tagName();
-        if (UMLDoc::tagEq(tag, "Stereotype")) {
-            stereo = stereoElem.attribute("xmi.idref", "");
+        if (UMLDoc::tagEq(tag, QLatin1String("Stereotype"))) {
+            stereo = stereoElem.attribute(QLatin1String("xmi.idref"));
         }
     }
     if (stereo.isEmpty())
@@ -918,17 +918,13 @@ bool UMLObject::loadFromXMI(QDomElement & element)
     }
     // Read the name first so that if we encounter a problem, the error
     // message can say the name.
-    m_name = element.attribute("name", "");
-    QString id = element.attribute("xmi.id", "");
-    if (id.isEmpty() || id == "-1") {
-        if (m_BaseType == ot_Role) {
-            // Before version 1.4, Umbrello did not save the xmi.id
-            // of UMLRole objects.
-            m_nId = UniqueID::gen();
-        } else {
-            uError() << m_name << ": nonexistent or illegal xmi.id";
-            return false;
-        }
+    m_name = element.attribute(QLatin1String("name"));
+    QString id = Model_Utils::getXmiId(element);
+    if (id.isEmpty() || id == QLatin1String("-1")) {
+        // Before version 1.4, Umbrello did not save the xmi.id of UMLRole objects.
+        // Some tools (such as Embarcadero's) do not have an xmi.id on all attributes.
+        m_nId = UniqueID::gen();
+        uWarning() << m_name << ": xmi.id not present, generating a new one";
     } else {
         Uml::ID::Type nId = Uml::ID::fromString(id);
         if (m_BaseType == ot_Role) {
@@ -945,17 +941,17 @@ bool UMLObject::loadFromXMI(QDomElement & element)
         m_nId = nId;
     }
 
-    if (element.hasAttribute("documentation"))  // for bkwd compat.
-        m_Doc = element.attribute("documentation", "");
+    if (element.hasAttribute(QLatin1String("documentation")))  // for bkwd compat.
+        m_Doc = element.attribute(QLatin1String("documentation"));
     else
-        m_Doc = element.attribute("comment", "");    //CHECK: need a UML:Comment?
+        m_Doc = element.attribute(QLatin1String("comment"));    //CHECK: need a UML:Comment?
 
     m_visibility = Uml::Visibility::Public;
-    if (element.hasAttribute("scope")) {        // for bkwd compat.
-        QString scope = element.attribute("scope", "");
-        if (scope == "instance_level")         // nsuml compat.
+    if (element.hasAttribute(QLatin1String("scope"))) {        // for bkwd compat.
+        QString scope = element.attribute(QLatin1String("scope"));
+        if (scope == QLatin1String("instance_level"))         // nsuml compat.
             m_bStatic = false;
-        else if (scope == "classifier_level")  // nsuml compat.
+        else if (scope == QLatin1String("classifier_level"))  // nsuml compat.
             m_bStatic = true;
         else {
             int nScope = scope.toInt();
@@ -974,18 +970,18 @@ bool UMLObject::loadFromXMI(QDomElement & element)
             }
         }
     } else {
-        QString visibility = element.attribute("visibility", "public");
-        if (visibility == "private"
-                || visibility == "private_vis")    // for compatibility with other programs
+        QString visibility = element.attribute(QLatin1String("visibility"), QLatin1String("public"));
+        if (visibility == QLatin1String("private")
+                || visibility == QLatin1String("private_vis"))    // for compatibility with other programs
             m_visibility = Uml::Visibility::Private;
-        else if (visibility == "protected"
-                 || visibility == "protected_vis")  // for compatibility with other programs
+        else if (visibility == QLatin1String("protected")
+                 || visibility == QLatin1String("protected_vis"))  // for compatibility with other programs
             m_visibility = Uml::Visibility::Protected;
-        else if (visibility == "implementation")
+        else if (visibility == QLatin1String("implementation"))
             m_visibility = Uml::Visibility::Implementation;
     }
 
-    QString stereo = element.attribute("stereotype", "");
+    QString stereo = element.attribute(QLatin1String("stereotype"));
     if (!stereo.isEmpty()) {
         Uml::ID::Type stereoID = Uml::ID::fromString(stereo);
         m_pStereotype = umldoc->findStereotypeById(stereoID);
@@ -998,20 +994,20 @@ bool UMLObject::loadFromXMI(QDomElement & element)
         }
     }
 
-    if (element.hasAttribute("abstract")) {      // for bkwd compat.
-        QString abstract = element.attribute("abstract", "0");
+    if (element.hasAttribute(QLatin1String("abstract"))) {      // for bkwd compat.
+        QString abstract = element.attribute(QLatin1String("abstract"), QLatin1String("0"));
         m_bAbstract = (bool)abstract.toInt();
     } else {
-        QString isAbstract = element.attribute("isAbstract", "false");
-        m_bAbstract = (isAbstract == "true");
+        QString isAbstract = element.attribute(QLatin1String("isAbstract"), QLatin1String("false"));
+        m_bAbstract = (isAbstract == QLatin1String("true"));
     }
 
-    if (element.hasAttribute("static")) {        // for bkwd compat.
-        QString staticScope = element.attribute("static", "0");
+    if (element.hasAttribute(QLatin1String("static"))) {        // for bkwd compat.
+        QString staticScope = element.attribute(QLatin1String("static"), QLatin1String("0"));
         m_bStatic = (bool)staticScope.toInt();
     } else {
-        QString ownerScope = element.attribute("ownerScope", "instance");
-        m_bStatic = (ownerScope == "classifier");
+        QString ownerScope = element.attribute(QLatin1String("ownerScope"), QLatin1String("instance"));
+        m_bStatic = (ownerScope == QLatin1String("classifier"));
     }
 
     // If the node has child nodes, check whether attributes can be
@@ -1023,30 +1019,30 @@ bool UMLObject::loadFromXMI(QDomElement & element)
         QDomElement elem = node.toElement();
         while (!elem.isNull()) {
             QString tag = elem.tagName();
-            if (UMLDoc::tagEq(tag, "name")) {
-                m_name = elem.attribute("xmi.value", "");
+            if (UMLDoc::tagEq(tag, QLatin1String("name"))) {
+                m_name = elem.attribute(QLatin1String("xmi.value"));
                 if (m_name.isEmpty())
                     m_name = elem.text();
-            } else if (UMLDoc::tagEq(tag, "visibility")) {
-                QString vis = elem.attribute("xmi.value", "");
+            } else if (UMLDoc::tagEq(tag, QLatin1String("visibility"))) {
+                QString vis = elem.attribute(QLatin1String("xmi.value"));
                 if (vis.isEmpty())
                     vis = elem.text();
-                if (vis == "private" || vis == "private_vis")
+                if (vis == QLatin1String("private") || vis == QLatin1String("private_vis"))
                     m_visibility = Uml::Visibility::Private;
-                else if (vis == "protected" || vis == "protected_vis")
+                else if (vis == QLatin1String("protected") || vis == QLatin1String("protected_vis"))
                     m_visibility = Uml::Visibility::Protected;
-                else if (vis == "implementation")
+                else if (vis == QLatin1String("implementation"))
                     m_visibility = Uml::Visibility::Implementation;
-            } else if (UMLDoc::tagEq(tag, "isAbstract")) {
-                QString isAbstract = elem.attribute("xmi.value", "");
+            } else if (UMLDoc::tagEq(tag, QLatin1String("isAbstract"))) {
+                QString isAbstract = elem.attribute(QLatin1String("xmi.value"));
                 if (isAbstract.isEmpty())
                     isAbstract = elem.text();
-                m_bAbstract = (isAbstract == "true");
-            } else if (UMLDoc::tagEq(tag, "ownerScope")) {
-                QString ownerScope = elem.attribute("xmi.value", "");
+                m_bAbstract = (isAbstract == QLatin1String("true"));
+            } else if (UMLDoc::tagEq(tag, QLatin1String("ownerScope"))) {
+                QString ownerScope = elem.attribute(QLatin1String("xmi.value"));
                 if (ownerScope.isEmpty())
                     ownerScope = elem.text();
-                m_bStatic = (ownerScope == "classifier");
+                m_bStatic = (ownerScope == QLatin1String("classifier"));
             } else {
                 loadStereotype(elem);
             }
