@@ -14,17 +14,18 @@
 // local includes
 #include "association.h"
 #include "associationwidget.h"
-#include "assocpropdlg.h"
+#include "associationpropertiesdialog.h"
 #include "classifier.h"
 #include "cmds.h"
 #include "debug_utils.h"
 #include "linkwidget.h"
+#include "classifierwidget.h"
 #include "listpopupmenu.h"
 #include "messagewidget.h"
 #include "model_utils.h"
 #include "object_factory.h"
 #include "operation.h"
-#include "selectopdlg.h"
+#include "selectoperationdialog.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlview.h"
@@ -89,7 +90,7 @@ QString FloatingTextWidget::text() const
     // the text -b.t.
     if (m_textRole == Uml::TextRole::Seq_Message || m_textRole == Uml::TextRole::Seq_Message_Self ||
             m_textRole == Uml::TextRole::Coll_Message || m_textRole == Uml::TextRole::Coll_Message_Self) {
-        if (m_Text.length() <= 1 || m_Text == ": ")
+        if (m_Text.length() <= 1 || m_Text == QLatin1String(": "))
             return QString();
     }
     return m_Text;
@@ -103,11 +104,12 @@ QString FloatingTextWidget::text() const
 void FloatingTextWidget::setText(const QString &t)
 {
     if (m_textRole == Uml::TextRole::Seq_Message || m_textRole == Uml::TextRole::Seq_Message_Self) {
-        QString seqNum, op;
-        m_linkWidget->seqNumAndOp(seqNum, op);
+        QString op;
+        if (m_linkWidget)
+            op = m_linkWidget->lwOperationText();
         if (op.length() > 0) {
             if (!m_scene->showOpSig())
-                op.replace(QRegExp("\\(.*\\)"), "()");
+                op.replace(QRegExp(QLatin1String("\\(.*\\)")), QLatin1String("()"));
             m_Text = op;
         }
         else
@@ -156,7 +158,7 @@ QString FloatingTextWidget::displayText() const
 {
     QString displayText;
     if (!m_SequenceNumber.isEmpty())
-        displayText = m_SequenceNumber + ": " + m_Text;
+        displayText = m_SequenceNumber + QLatin1String(": ") + m_Text;
     else
         displayText = m_Text;
     displayText.prepend(m_preText);
@@ -164,10 +166,19 @@ QString FloatingTextWidget::displayText() const
     return displayText;
 }
 
+/**
+ * Return state if no pre, post and main text is empty
+ * @return true if widget contains no text
+ */
+bool FloatingTextWidget::isEmpty()
+{
+    return m_Text.isEmpty() && m_preText.isEmpty() && m_postText.isEmpty();
+}
+
 /**
  * Overrides method from UMLWidget.
  */
-QSizeF FloatingTextWidget::minimumSize()
+QSizeF FloatingTextWidget::minimumSize() const
 {
     const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
     int h = fm.lineSpacing();
@@ -214,28 +225,29 @@ void FloatingTextWidget::showOperationDialog(bool enableAutoIncrement)
         uError() << "m_linkWidget is NULL";
         return;
     }
-    QString seqNum, opText;
-    UMLClassifier* c = m_linkWidget->seqNumAndOp(seqNum, opText);
+    QString seqNum = m_linkWidget->sequenceNumber();
+    UMLClassifier* c = m_linkWidget->lwClassifier();
+    QString opText = m_linkWidget->lwOperationText();
     if (!c) {
-        uError() << "m_linkWidget->seqNumAndOp() returns a NULL classifier";
+        uError() << "m_linkWidget->lwClassifier() returns a NULL classifier";
         return;
     }
 
-    QPointer<SelectOpDlg> selectDlg = new SelectOpDlg(m_scene->activeView(), c, enableAutoIncrement);
+    QPointer<SelectOperationDialog> selectDialog = new SelectOperationDialog(m_scene->activeView(), c, enableAutoIncrement);
     if (enableAutoIncrement && m_scene->autoIncrementSequence()) {
         seqNum = m_scene->autoIncrementSequenceValue();
-        selectDlg->setAutoIncrementSequence(true);
+        selectDialog->setAutoIncrementSequence(true);
     }
-    selectDlg->setSeqNumber(seqNum);
+    selectDialog->setSeqNumber(seqNum);
     if (m_linkWidget->operation() == 0) {
-        selectDlg->setCustomOp(opText);
+        selectDialog->setCustomOp(opText);
     } else {
-        selectDlg->setClassOp(opText);
+        selectDialog->setClassOp(opText);
     }
-    if (selectDlg->exec()) {
-        seqNum = selectDlg->getSeqNumber();
-        opText = selectDlg->getOpText();
-        if (selectDlg->isClassOp()) {
+    if (selectDialog->exec()) {
+        seqNum = selectDialog->getSeqNumber();
+        opText = selectDialog->getOpText();
+        if (selectDialog->isClassOp()) {
             Model_Utils::OpDescriptor od;
             Model_Utils::Parse_Status st = Model_Utils::parseOperation(opText, od, c);
             if (st == Model_Utils::PS_OK) {
@@ -265,13 +277,14 @@ void FloatingTextWidget::showOperationDialog(bool enableAutoIncrement)
         } else {
             m_linkWidget->setOperation(0);
         }
-        m_linkWidget->setSeqNumAndOp(seqNum, opText);
+        m_linkWidget->setSequenceNumber(seqNum);
+        m_linkWidget->setOperationText(opText);
         if (enableAutoIncrement) {
-            m_scene->setAutoIncrementSequence(selectDlg->autoIncrementSequence());
+            m_scene->setAutoIncrementSequence(selectDialog->autoIncrementSequence());
         }
         setMessageText();
     }
-    delete selectDlg;
+    delete selectDialog;
 }
 
 /**
@@ -374,7 +387,7 @@ Uml::TextRole::Enum FloatingTextWidget::textRole() const
  */
 void FloatingTextWidget::handleRename()
 {
-    QRegExpValidator v(QRegExp(".*"), 0);
+    QRegExpValidator v(QRegExp(QLatin1String(".*")), 0);
     QString t;
     if (m_textRole == Uml::TextRole::RoleAName || m_textRole == Uml::TextRole::RoleBName) {
         t = i18n("Enter role name:");
@@ -444,7 +457,8 @@ void FloatingTextWidget::changeName(const QString& newText)
         return;
     }
 
-    if (m_linkWidget && m_textRole != Uml::TextRole::Seq_Message && m_textRole != Uml::TextRole::Seq_Message_Self) {
+    if (m_linkWidget && m_textRole != Uml::TextRole::Seq_Message
+                     && m_textRole != Uml::TextRole::Seq_Message_Self) {
         m_linkWidget->setText(this, newText);
     }
     else {
@@ -603,6 +617,49 @@ void FloatingTextWidget::constrainMovementForAllWidgets(qreal &diffX, qreal &dif
     diffY = constrainedPosition.y() - y();
 }
 
+/**
+ * Override method from UMLWidget in order to additionally check widget parentage.
+ *
+ * @param p Point to be checked.
+ *
+ * @return 'this' if UMLWidget::onWidget(p) returns non NULL;
+ *         else NULL.
+ */
+UMLWidget* FloatingTextWidget::onWidget(const QPointF &p)
+{
+    WidgetBase *pw = dynamic_cast<WidgetBase*>(parentItem());
+    if (pw == NULL) {
+        return WidgetBase::onWidget(p);
+    }
+    const WidgetBase::WidgetType t = pw->baseType();
+    bool isWidgetChild = false;
+    if (t == WidgetBase::wt_Interface) {
+        ClassifierWidget *cw = static_cast<ClassifierWidget*>(pw);
+        isWidgetChild = cw->getDrawAsCircle();
+    } else if (t == wt_Association ||
+               t == WidgetBase::wt_Port || t == WidgetBase::wt_Pin) {
+        isWidgetChild = true;
+    }
+    if (!isWidgetChild) {
+        return WidgetBase::onWidget(p);
+    }
+    const qreal w = width();
+    const qreal h = height();
+    const qreal left = pw->x() + x();
+    const qreal right = left + w;
+    const qreal top = pw->y() + y();
+    const qreal bottom = top + h;
+    // uDebug() << "child_of_pw; p=(" << p.x() << "," << p.y() << "), "
+    //          << "x=" << left << ", y=" << top << ", w=" << w << ", h=" << h
+    //          << "; right=" << right << ", bottom=" << bottom;
+    if (p.x() >= left && p.x() <= right &&
+        p.y() >= top && p.y() <= bottom) { // Qt coord.sys. origin in top left corner
+        // uDebug() << "floatingtext: " << m_Text;
+        return this;
+    }
+    return NULL;
+}
+
 /**
  * Overrides default method
  */
@@ -630,20 +687,20 @@ bool FloatingTextWidget::loadFromXMI(QDomElement & qElement)
 
     m_unconstrainedPositionX = x();
     m_unconstrainedPositionY = y();
-    QString role = qElement.attribute("role", "");
+    QString role = qElement.attribute(QLatin1String("role"));
     if(!role.isEmpty())
         m_textRole = Uml::TextRole::fromInt(role.toInt());
 
-    m_preText = qElement.attribute("pretext", "");
-    m_postText = qElement.attribute("posttext", "");
-    m_Text = qElement.attribute("text", "");
+    m_preText = qElement.attribute(QLatin1String("pretext"));
+    m_postText = qElement.attribute(QLatin1String("posttext"));
+    setText(qElement.attribute(QLatin1String("text")));  // use setText for geometry update
     // If all texts are empty then this is a useless widget.
     // In that case we return false.
     // CAVEAT: The caller should not interpret the false return value
     //  as an indication of failure since previous umbrello versions
     //  saved lots of these empty FloatingTexts.
-    bool usefullWidget = !(m_Text.isEmpty() && m_preText.isEmpty() && m_postText.isEmpty());
-    return usefullWidget;
+    bool usefulWidget = !isEmpty();
+    return usefulWidget;
 }
 
 /**
@@ -652,18 +709,21 @@ bool FloatingTextWidget::loadFromXMI(QDomElement & qElement)
  */
 void FloatingTextWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
-    QDomElement textElement = qDoc.createElement("floatingtext");
+    if (isEmpty())
+        return;
+
+    QDomElement textElement = qDoc.createElement(QLatin1String("floatingtext"));
     UMLWidget::saveToXMI(qDoc, textElement);
-    textElement.setAttribute("text", m_Text);
-    textElement.setAttribute("pretext", m_preText);
-    textElement.setAttribute("posttext", m_postText);
+    textElement.setAttribute(QLatin1String("text"), m_Text);
+    textElement.setAttribute(QLatin1String("pretext"), m_preText);
+    textElement.setAttribute(QLatin1String("posttext"), m_postText);
 
     /* No need to save these - the messagewidget already did it.
-    m_Operation  = qElement.attribute("operation", "");
-    m_SeqNum = qElement.attribute("seqnum", "");
+    m_Operation  = qElement.attribute("operation");
+    m_SeqNum = qElement.attribute("seqnum");
      */
 
-    textElement.setAttribute("role", m_textRole);
+    textElement.setAttribute(QLatin1String("role"), m_textRole);
     qElement.appendChild(textElement);
 }
 
@@ -681,6 +741,9 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
         break;
 
     case ListPopupMenu::mt_Delete:
+        hide();   // This is only a workaround; if set then m_linkWidget should
+                  // really delete this FloatingTextWidget.
+        update();
         m_scene->removeWidget(this);
         break;
 
