@@ -12,7 +12,7 @@
 #include "objectwidget.h"
 
 // local includes
-#include "classpropdlg.h"
+#include "classpropertiesdialog.h"
 #include "debug_utils.h"
 #include "docwindow.h"
 #include "listpopupmenu.h"
@@ -52,7 +52,6 @@ static const int sequenceLineMargin = 20;
  *
  * @param scene   The parent to this object.
  * @param o       The object it will be representing.
- * @param lid     The local id for the object.
  */
 ObjectWidget::ObjectWidget(UMLScene * scene, UMLObject *o)
   : UMLWidget(scene, WidgetBase::wt_Object, o),
@@ -163,7 +162,7 @@ void ObjectWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Rename_Object:
         {
             bool ok;
-            QRegExpValidator* validator = new QRegExpValidator(QRegExp(".*"), 0);
+            QRegExpValidator* validator = new QRegExpValidator(QRegExp(QLatin1String(".*")), 0);
             QString name = KInputDialog::getText
                    (i18n("Rename Object"),
                     i18n("Enter object name:"),
@@ -205,12 +204,12 @@ void ObjectWidget::slotMenuSelection(QAction* action)
 /**
  * Overrides method from UMLWidget
  */
-QSizeF ObjectWidget::minimumSize()
+QSizeF ObjectWidget::minimumSize() const
 {
     int width, height;
     const QFontMetrics &fm = getFontMetrics(FT_UNDERLINE);
     const int fontHeight  = fm.lineSpacing();
-    const QString t = m_instanceName + " : " + name();
+    const QString t = m_instanceName + QLatin1String(" : ") + name();
     const int textWidth = fm.width(t);
     if (m_drawAsActor) {
         width = textWidth > A_WIDTH?textWidth:A_WIDTH;
@@ -391,7 +390,7 @@ void ObjectWidget::cleanup()
 void ObjectWidget::showPropertiesDialog()
 {
     UMLApp::app()->docWindow()->updateDocumentation(false);
-    QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this);
+    QPointer<ClassPropertiesDialog> dlg = new ClassPropertiesDialog((QWidget*)UMLApp::app(), this);
     if (dlg->exec()) {
         UMLApp::app()->docWindow()->showDocumentation(this, true);
         UMLApp::app()->document()->setModified(true);
@@ -418,7 +417,7 @@ void ObjectWidget::paintObject(QPainter *painter)
     const int w = width();
     const int h = height();
 
-    const QString t = m_instanceName + " : " + name();
+    const QString t = m_instanceName + QLatin1String(" : ") + name();
     int multiInstOfst = 0;
     if (m_multipleInstance) {
         painter->drawRect(10, 10, w - 10, h - 10);
@@ -462,7 +461,7 @@ void ObjectWidget::paintActor(QPainter *painter)
                middleX + A_WIDTH / 2, thirdH + thirdH / 2);//arms
     //draw text
     painter->setPen(textColor());
-    QString t = m_instanceName + " : " + name();
+    QString t = m_instanceName + QLatin1String(" : ") + name();
     painter->drawText(A_MARGIN, textStartY,
                w - A_MARGIN * 2, fontHeight, Qt::AlignCenter, t);
 }
@@ -668,11 +667,11 @@ void ObjectWidget::resizeWidget(qreal newW, qreal newH)
  */
 void ObjectWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
-    QDomElement objectElement = qDoc.createElement("objectwidget");
+    QDomElement objectElement = qDoc.createElement(QLatin1String("objectwidget"));
     UMLWidget::saveToXMI(qDoc, objectElement);
-    objectElement.setAttribute("drawasactor", m_drawAsActor);
-    objectElement.setAttribute("multipleinstance", m_multipleInstance);
-    objectElement.setAttribute("decon", m_showDestruction);
+    objectElement.setAttribute(QLatin1String("drawasactor"), m_drawAsActor);
+    objectElement.setAttribute(QLatin1String("multipleinstance"), m_multipleInstance);
+    objectElement.setAttribute(QLatin1String("decon"), m_showDestruction);
     qElement.appendChild(objectElement);
 }
 
@@ -683,9 +682,9 @@ bool ObjectWidget::loadFromXMI(QDomElement& qElement)
 {
     if(!UMLWidget::loadFromXMI(qElement))
         return false;
-    QString draw = qElement.attribute("drawasactor", "0");
-    QString multi = qElement.attribute("multipleinstance", "0");
-    QString decon = qElement.attribute("decon", "0");
+    QString draw = qElement.attribute(QLatin1String("drawasactor"), QLatin1String("0"));
+    QString multi = qElement.attribute(QLatin1String("multipleinstance"), QLatin1String("0"));
+    QString decon = qElement.attribute(QLatin1String("decon"), QLatin1String("0"));
 
     m_drawAsActor = (bool)draw.toInt();
     m_multipleInstance = (bool)multi.toInt();
