@@ -13,14 +13,14 @@
 // local includes
 #include "associationwidget.h"
 #include "classifier.h"
-#include "classpropdlg.h"
+#include "classpropertiesdialog.h"
 #include "cmds.h"
 #include "debug_utils.h"
 #include "docwindow.h"
 #include "floatingtextwidget.h"
 #include "idchangelog.h"
 #include "listpopupmenu.h"
-#include "settingsdlg.h"
+#include "settingsdialog.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umllistview.h"
@@ -36,6 +36,7 @@
 #include <kmessagebox.h>
 
 // qt includes
+#include <QApplication>
 #include <QColor>
 #include <QPainter>
 #include <QPointer>
@@ -51,6 +52,8 @@ const QSizeF UMLWidget::DefaultMaximumSize(1000, 5000);
  * Creates a UMLWidget object.
  *
  * @param scene The view to be displayed on.
+ * @param type  The WidgetType to construct.
+ *              This must be set to the appropriate value by the constructors of inheriting classes.
  * @param o The UMLObject to represent.
  */
 UMLWidget::UMLWidget(UMLScene * scene, WidgetType type, UMLObject * o)
@@ -68,6 +71,8 @@ UMLWidget::UMLWidget(UMLScene * scene, WidgetType type, UMLObject * o)
  * Creates a UMLWidget object.
  *
  * @param scene The view to be displayed on.
+ * @param type  The WidgetType to construct.
+ *              This must be set to the appropriate value by the constructors of inheriting classes.
  * @param id The id of the widget.
  *  The default value (id_None) will prompt generation of a new ID.
  */
@@ -199,12 +204,33 @@ Uml::ID::Type UMLWidget::localID() const
     return m_nLocalID;
 }
 
+/**
+ * Returns the widget with the given ID.
+ * The default implementation tests the following IDs:
+ * - m_nLocalID
+ * - if m_umlObject is non NULL: m_umlObject->id()
+ * - m_nID
+ * Composite widgets override this function to test further owned widgets.
+ *
+ * @param id  The ID to test this widget against.
+ * @return  'this' if id is either of m_nLocalID, m_umlObject->id(), or m_nId;
+ *           else NULL.
+ */
+UMLWidget* UMLWidget::widgetWithID(Uml::ID::Type id)
+{
+    if (id == m_nLocalID ||
+        (m_umlObject != NULL && id == m_umlObject->id()) ||
+        id == m_nId)
+        return this;
+    return NULL;
+}
+
 /**
  * Compute the minimum possible width and height.
  *
  * @return QSizeF(mininum_width, minimum_height)
  */
-QSizeF UMLWidget::minimumSize()
+QSizeF UMLWidget::minimumSize() const
 {
     return m_minimumSize;
 }
@@ -414,9 +440,9 @@ void UMLWidget::mousePressEvent(QGraphicsSceneMouseEvent *event)
  * on the widget. Go on reading for more info about this.
  *
  * If resizing, the widget is resized using UMLWidget::resizeWidget (where specific
- * widget resize constrain can be applied), and then the associations are
+ * widget resize constraint can be applied), and then the associations are
  * adjusted.
- * The resizing can be constrained also to an specific axis using control
+ * The resizing can be constrained also to a specific axis using control
  * and shift buttons. If on or another is pressed, it's constrained to X axis.
  * If both are pressed, it's constrained to Y axis.
  *
@@ -427,12 +453,12 @@ void UMLWidget::mousePressEvent(QGraphicsSceneMouseEvent *event)
  * one is got (taking in account the selection bounds so widgets don't go
  * beyond the scene limits). Then, it's constrained to X or Y axis depending
  * on shift and control buttons.
- * A further constrain is made using constrainMovementForAllWidgets (for example,
+ * A further constraint is made using constrainMovementForAllWidgets (for example,
  * if the widget that receives the event can only be moved in Y axis, with this
  * method the movement of all the widgets in the selection can be constrained to
  * be moved only in Y axis).
  * Then, all the selected widgets are moved using moveWidgetBy (where specific
- * widget movement constrain can be applied) and, if an specific amount of time
+ * widget movement constraint can be applied) and, if a certain amount of time
  * passed from the last move event, the associations are also updated (they're
  * not updated always to be easy on the CPU). Finally, the scene is resized,
  * and selection bounds updated.
@@ -589,6 +615,15 @@ QPointF UMLWidget::startMovePosition() const
     return m_startMovePostion;
 }
 
+/**
+ * Set the start position of the move action.
+ * @param position point where the move began
+ */
+void UMLWidget::setStartMovePosition(const QPointF &position)
+{
+    m_startMovePostion = position;
+}
+
 /**
  * Return the start size of the resize action.
  * @return   size where the resize began
@@ -674,8 +709,11 @@ void UMLWidget::init()
     setMinimumSize(DefaultMinimumSize);
     setMaximumSize(DefaultMaximumSize);
 
-    for (int i = 0; i < (int)FT_INVALID; ++i) {
-        m_pFontMetrics[(UMLWidget::FontType)i] = 0;
+    m_font = QApplication::font();
+    for (int i = (int)FT_INVALID - 1; i >= 0; --i) {
+        FontType fontType = (FontType)i;
+        setupFontType(m_font, fontType);
+        m_pFontMetrics[fontType] = new QFontMetrics(m_font);
     }
 
     if (m_scene) {
@@ -702,8 +740,6 @@ void UMLWidget::init()
     m_ignoreSnapComponentSizeToGrid = false;
     m_doc = UMLApp::app()->document();
     m_nPosX = 0;
-    connect(m_scene, SIGNAL(sigClearAllSelected()), this, SLOT(slotClearAllSelected()));
-
     connect(m_scene, SIGNAL(sigFillColorChanged(Uml::ID::Type)), this, SLOT(slotFillColorChanged(Uml::ID::Type)));
     connect(m_scene, SIGNAL(sigLineColorChanged(Uml::ID::Type)), this, SLOT(slotLineColorChanged(Uml::ID::Type)));
     connect(m_scene, SIGNAL(sigTextColorChanged(Uml::ID::Type)), this, SLOT(slotTextColorChanged(Uml::ID::Type)));
@@ -764,7 +800,7 @@ void UMLWidget::slotWidgetMoved(Uml::ID::Type /*id*/)
 /**
  * Captures a color change signal.
  *
- * @param sceneID The id of the object behind the widget.
+ * @param viewID  The id of the UMLScene behind the widget.
  */
 void UMLWidget::slotFillColorChanged(Uml::ID::Type viewID)
 {
@@ -784,7 +820,7 @@ void UMLWidget::slotFillColorChanged(Uml::ID::Type viewID)
 /**
  * Captures a text color change signal.
  *
- * @param sceneID The id of the object behind the widget.
+ * @param viewID  The id of the UMLScene behind the widget.
  */
 void UMLWidget::slotTextColorChanged(Uml::ID::Type viewID)
 {
@@ -799,7 +835,7 @@ void UMLWidget::slotTextColorChanged(Uml::ID::Type viewID)
 /**
  * Captures a line color change signal.
  *
- * @param sceneID The id of the object behind the widget.
+ * @param viewID  The id of the UMLScene behind the widget.
  */
 void UMLWidget::slotLineColorChanged(Uml::ID::Type viewID)
 {
@@ -816,7 +852,7 @@ void UMLWidget::slotLineColorChanged(Uml::ID::Type viewID)
 /**
  * Captures a linewidth change signal.
  *
- * @param sceneID The id of the object behind the widget.
+ * @param viewID  The id of the UMLScene behind the widget.
  */
 void UMLWidget::slotLineWidthChanged(Uml::ID::Type viewID)
 {
@@ -1015,7 +1051,7 @@ bool UMLWidget::isActivated() const
 /**
  * Set the m_activated flag of a widget but does not perform the Activate method
  *
- * @param Active Status of activation is to be set.
+ * @param active  Status of activation is to be set.
  */
 void UMLWidget::setActivated(bool active /*=true*/)
 {
@@ -1047,8 +1083,8 @@ void UMLWidget::removeAssoc(AssociationWidget* pAssoc)
 /**
  * Adjusts associations with the given co-ordinates
  *
- * @param x The x-coordinate.
- * @param y The y-coordinate.
+ * @param dx  The amount by which the widget moved in X direction.
+ * @param dy  The amount by which the widget moved in Y direction.
  */
 void UMLWidget::adjustAssocs(qreal dx, qreal dy)
 {
@@ -1077,8 +1113,8 @@ void UMLWidget::adjustAssocs(qreal dx, qreal dy)
 /**
  * Adjusts all unselected associations with the given co-ordinates
  *
- * @param x The x-coordinate.
- * @param y The y-coordinate.
+ * @param dx  The amount by which the widget moved in X direction.
+ * @param dy  The amount by which the widget moved in Y direction.
  */
 void UMLWidget::adjustUnselectedAssocs(qreal dx, qreal dy)
 {
@@ -1102,7 +1138,7 @@ void UMLWidget::showPropertiesDialog()
     // will already be selected so make sure docWindow updates the doc
     // back it the widget
     UMLApp::app()->docWindow()->updateDocumentation(false);
-    QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this);
+    QPointer<ClassPropertiesDialog> dlg = new ClassPropertiesDialog((QWidget*)UMLApp::app(), this);
 
     if (dlg->exec()) {
         UMLApp::app()->docWindow()->showDocumentation(umlObject(), true);
@@ -1112,29 +1148,6 @@ void UMLWidget::showPropertiesDialog()
     delete dlg;
 }
 
-/**
- * Returns 0 if the given point is not in the boundaries of the widget,
- * else returns a number which is proportional to the size of the widget.
- *
- * @param p Point to be checked.
- *
- * @return 0 if the given point is not in the boundaries of the widget;
- *         (width()+height())/2 if the point is within the boundaries.
- */
-qreal UMLWidget::onWidget(const QPointF &p)
-{
-    const qreal w = width();
-    const qreal h = height();
-    const qreal left = x();
-    const qreal right = left + w;
-    const qreal top = y();
-    const qreal bottom = top + h;
-    if (p.x() < left || p.x() > right ||
-            p.y() < top || p.y() > bottom)   // Qt coord.sys. origin in top left corner
-        return 0;
-    return (w + h) / 2;
-}
-
 /**
  * Move the widget by an X and Y offset relative to
  * the current position.
@@ -1211,8 +1224,9 @@ bool UMLWidget::isInResizeArea(QGraphicsSceneMouseEvent *me)
  *
  * @return calculated widget size
  */
-QSizeF UMLWidget::calculateSize()
+QSizeF UMLWidget::calculateSize(bool withExtensions /* = true */) const
 {
+    Q_UNUSED(withExtensions)
     return QSizeF(width(), height());
 }
 
@@ -1351,14 +1365,6 @@ void UMLWidget::setSelected(bool _select)
     }
 }
 
-/**
- *   Captures a sigClearAllSelected signal sent by @ref UMLView
- */
-void UMLWidget::slotClearAllSelected()
-{
-    setSelected(false);
-}
-
 /**
  * Selects the widget and clears the other selected widgets, if any.
  *
@@ -1410,17 +1416,15 @@ void UMLWidget::deselect(QGraphicsSceneMouseEvent *me)
 /**
  * Sets the view the widget is on.
  *
- * @param v The view the widget is on.
+ * @param scene  The UMLScene the widget is on.
  */
 void UMLWidget::setScene(UMLScene *scene)
 {
     //remove signals from old view - was probably 0 anyway
-    disconnect(m_scene, SIGNAL(sigClearAllSelected()), this, SLOT(slotClearAllSelected()));
     disconnect(m_scene, SIGNAL(sigFillColorChanged(Uml::ID::Type)), this, SLOT(slotFillColorChanged(Uml::ID::Type)));
     disconnect(m_scene, SIGNAL(sigTextColorChanged(Uml::ID::Type)), this, SLOT(slotTextColorChanged(Uml::ID::Type)));
     disconnect(m_scene, SIGNAL(sigLineWidthChanged(Uml::ID::Type)), this, SLOT(slotLineWidthChanged(Uml::ID::Type)));
     m_scene = scene;
-    connect(m_scene, SIGNAL(sigClearAllSelected()), this, SLOT(slotClearAllSelected()));
     connect(m_scene, SIGNAL(sigFillColorChanged(Uml::ID::Type)), this, SLOT(slotFillColorChanged(Uml::ID::Type)));
     connect(m_scene, SIGNAL(sigTextColorChanged(Uml::ID::Type)), this, SLOT(slotTextColorChanged(Uml::ID::Type)));
     connect(m_scene, SIGNAL(sigLineWidthChanged(Uml::ID::Type)), this, SLOT(slotLineWidthChanged(Uml::ID::Type)));
@@ -1485,6 +1489,7 @@ bool UMLWidget::widgetHasUMLObject(WidgetBase::WidgetType type)
             type == WidgetBase::wt_Datatype  ||
             type == WidgetBase::wt_Package   ||
             type == WidgetBase::wt_Component ||
+            type == WidgetBase::wt_Port ||
             type == WidgetBase::wt_Node      ||
             type == WidgetBase::wt_Artifact  ||
             type == WidgetBase::wt_Object) {
@@ -1656,7 +1661,7 @@ void UMLWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
             painter->fillRect(0 + w - s, 0 + h - s, s, s, brush);
         }
         // debug info
-        if (Tracer::instance()->isEnabled(metaObject()->className())) {
+        if (Tracer::instance()->isEnabled(QLatin1String(metaObject()->className()))) {
             painter->setPen(Qt::green);
             painter->setBrush(Qt::NoBrush);
             painter->drawPath(shape());
@@ -1693,11 +1698,8 @@ void UMLWidget::setDefaultFontMetrics(QFont &font, UMLWidget::FontType fontType,
  * Returns the font metric used by this object for Text
  * which uses bold/italic fonts.
  */
-QFontMetrics &UMLWidget::getFontMetrics(UMLWidget::FontType fontType)
+QFontMetrics &UMLWidget::getFontMetrics(UMLWidget::FontType fontType) const
 {
-    if (m_pFontMetrics[fontType] == 0) {
-        setDefaultFontMetrics(m_font, fontType);
-    }
     return *m_pFontMetrics[fontType];
 }
 
@@ -1751,18 +1753,18 @@ void UMLWidget::forceUpdateFontMetrics(QPainter *painter)
  * @note For performance Reasons, only FontMetrics for already used
  *  font types are updated. Not yet used font types will not get a font metric
  *  and will get the same font metric as if painter was zero.
- *  This behaviour is acceptable, because diagrams will always be showed on Display
+ *  This behaviour is acceptable, because diagrams will always be shown on Display
  *  first before a special painter like a printer device is used.
  */
 void UMLWidget::forceUpdateFontMetrics(QFont& font, QPainter *painter)
 {
     if (painter == 0) {
-        for (int i = 0; i < (int)UMLWidget::FT_INVALID; ++i) {
+        for (int i = (int)FT_INVALID - 1; i >= 0; --i) {
             if (m_pFontMetrics[(UMLWidget::FontType)i] != 0)
                 setDefaultFontMetrics(font, (UMLWidget::FontType)i);
         }
     } else {
-        for (int i2 = 0; i2 < (int)UMLWidget::FT_INVALID; ++i2) {
+        for (int i2 = (int)FT_INVALID - 1; i2 >= 0; --i2) {
             if (m_pFontMetrics[(UMLWidget::FontType)i2] != 0)
                 setDefaultFontMetrics(font, (UMLWidget::FontType)i2, *painter);
         }
@@ -1800,8 +1802,9 @@ bool UMLWidget::showStereotype() const
  *
  * @param me The move event.
  */
-void UMLWidget::moveEvent(QGraphicsSceneMouseEvent* /*me*/)
+void UMLWidget::moveEvent(QGraphicsSceneMouseEvent* me)
 {
+  Q_UNUSED(me)
 }
 
 void UMLWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
@@ -1811,44 +1814,44 @@ void UMLWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
       Type must be set in the child class.
     */
     WidgetBase::saveToXMI(qDoc, qElement);
-    qElement.setAttribute("xmi.id", Uml::ID::toString(id()));
-    qElement.setAttribute("x", x());
-    qElement.setAttribute("y", y());
-    qElement.setAttribute("width", width());
-    qElement.setAttribute("height", height());
-    qElement.setAttribute("isinstance", m_isInstance);
+    qElement.setAttribute(QLatin1String("xmi.id"), Uml::ID::toString(id()));
+    qElement.setAttribute(QLatin1String("x"), x());
+    qElement.setAttribute(QLatin1String("y"), y());
+    qElement.setAttribute(QLatin1String("width"), width());
+    qElement.setAttribute(QLatin1String("height"), height());
+    qElement.setAttribute(QLatin1String("isinstance"), m_isInstance);
     if (!m_instanceName.isEmpty())
-        qElement.setAttribute("instancename", m_instanceName);
+        qElement.setAttribute(QLatin1String("instancename"), m_instanceName);
     if (m_showStereotype)
-        qElement.setAttribute("showstereotype", m_showStereotype);
+        qElement.setAttribute(QLatin1String("showstereotype"), m_showStereotype);
 
     // Unique identifier for widget (todo: id() should be unique, new attribute
     // should indicate the UMLObject's ID it belongs to)
-    qElement.setAttribute("localid", Uml::ID::toString(m_nLocalID));
+    qElement.setAttribute(QLatin1String("localid"), Uml::ID::toString(m_nLocalID));
 }
 
 bool UMLWidget::loadFromXMI(QDomElement & qElement)
 {
-    QString id = qElement.attribute("xmi.id", "-1");
+    QString id = qElement.attribute(QLatin1String("xmi.id"), QLatin1String("-1"));
     m_nId = Uml::ID::fromString(id);
 
     WidgetBase::loadFromXMI(qElement);
-    QString x = qElement.attribute("x", "0");
-    QString y = qElement.attribute("y", "0");
-    QString h = qElement.attribute("height", "0");
-    QString w = qElement.attribute("width", "0");
+    QString x = qElement.attribute(QLatin1String("x"), QLatin1String("0"));
+    QString y = qElement.attribute(QLatin1String("y"), QLatin1String("0"));
+    QString h = qElement.attribute(QLatin1String("height"), QLatin1String("0"));
+    QString w = qElement.attribute(QLatin1String("width"), QLatin1String("0"));
 
     setSize(w.toFloat(), h.toFloat());
     setX(x.toFloat());
     setY(y.toFloat());
-    QString isinstance = qElement.attribute("isinstance", "0");
+    QString isinstance = qElement.attribute(QLatin1String("isinstance"), QLatin1String("0"));
     m_isInstance = (bool)isinstance.toInt();
-    m_instanceName = qElement.attribute("instancename", "");
-    QString showstereo = qElement.attribute("showstereotype", "0");
+    m_instanceName = qElement.attribute(QLatin1String("instancename"));
+    QString showstereo = qElement.attribute(QLatin1String("showstereotype"), QLatin1String("0"));
     m_showStereotype = (bool)showstereo.toInt();
 
-    QString localid = qElement.attribute("localid", "0");
-    if (localid != "0") {
+    QString localid = qElement.attribute(QLatin1String("localid"), QLatin1String("0"));
+    if (localid != QLatin1String("0")) {
         m_nLocalID = Uml::ID::fromString(localid);
     }
 
