@@ -29,6 +29,8 @@
  * Creates a WidgetBase object.
  *
  * @param scene   The view to be displayed on.
+ * @param type    The WidgetType to construct.  This must be set to the appropriate
+ *                value by the constructors of inheriting classes.
  */
 WidgetBase::WidgetBase(UMLScene *scene, WidgetType type)
   : QGraphicsObject(),
@@ -130,7 +132,7 @@ UMLObject* WidgetBase::umlObject() const
 /**
  * Sets the @ref UMLObject to represent.
  *
- * @param o The object to represent.
+ * @param obj  The object to represent.
  */
 void WidgetBase::setUMLObject(UMLObject *obj)
 {
@@ -282,7 +284,7 @@ QColor WidgetBase::fillColor() const
 /**
  * Sets the fill color
  *
- * @param colour   The new fill color
+ * @param color   The new fill color
  */
 void WidgetBase::setFillColor(const QColor &color)
 {
@@ -447,10 +449,6 @@ QFont WidgetBase::font() const
 
 /**
  * Set the font used to display text inside this widget.
- *
- * This method issues @ref FontHasChanged notification after setting
- * the new font.
- * @see WidgetBase::attributeChange
  */
 void WidgetBase::setFont(const QFont& font)
 {
@@ -474,34 +472,34 @@ void WidgetBase::showPropertiesDialog()
  * called to save basic widget properties.
  *
  * @param qDoc A QDomDocument object representing the xml document.
- * @oaram qElement A QDomElement representing xml element data.
+ * @param qElement A QDomElement representing xml element data.
  */
 void WidgetBase::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  {
     Q_UNUSED(qDoc)
 
-    qElement.setAttribute("textcolor", m_usesDiagramTextColor ? "none" : m_textColor.name());
-
+    qElement.setAttribute(QLatin1String("textcolor"), m_usesDiagramTextColor ? QLatin1String("none")
+                                                                             : m_textColor.name());
     if (m_usesDiagramLineColor) {
-        qElement.setAttribute("linecolor", "none");
+        qElement.setAttribute(QLatin1String("linecolor"), QLatin1String("none"));
     } else {
-        qElement.setAttribute("linecolor", m_lineColor.name());
+        qElement.setAttribute(QLatin1String("linecolor"), m_lineColor.name());
     }
     if (m_usesDiagramLineWidth) {
-        qElement.setAttribute("linewidth", "none");
+        qElement.setAttribute(QLatin1String("linewidth"), QLatin1String("none"));
     } else {
-        qElement.setAttribute("linewidth", m_lineWidth);
+        qElement.setAttribute(QLatin1String("linewidth"), m_lineWidth);
     }
-    qElement.setAttribute("usefillcolor", m_useFillColor);
+    qElement.setAttribute(QLatin1String("usefillcolor"), m_useFillColor);
     // for consistency the following attributes now use american spelling for "color"
-    qElement.setAttribute("usesdiagramfillcolor", m_usesDiagramFillColor);
-    qElement.setAttribute("usesdiagramusefillcolor", m_usesDiagramUseFillColor);
+    qElement.setAttribute(QLatin1String("usesdiagramfillcolor"), m_usesDiagramFillColor);
+    qElement.setAttribute(QLatin1String("usesdiagramusefillcolor"), m_usesDiagramUseFillColor);
     if (m_usesDiagramFillColor) {
-        qElement.setAttribute("fillcolor", "none");
+        qElement.setAttribute(QLatin1String("fillcolor"), QLatin1String("none"));
     } else {
-        qElement.setAttribute("fillcolor", m_fillColor.name());
+        qElement.setAttribute(QLatin1String("fillcolor"), m_fillColor.name());
     }
-    qElement.setAttribute("font", m_font.toString());
+    qElement.setAttribute(QLatin1String("font"), m_font.toString());
 }
 
 /**
@@ -521,53 +519,53 @@ bool WidgetBase::loadFromXMI(QDomElement& qElement)
     // first load from "linecolour" and then overwrite with the "linecolor"
     // attribute if that one is present. The "linecolour" name was a "typo" in
     // earlier versions of Umbrello
-    QString lineColor = qElement.attribute("linecolour", "none");
-    lineColor = qElement.attribute("linecolor", lineColor);
-    if (lineColor != "none") {
+    QString lineColor = qElement.attribute(QLatin1String("linecolour"), QLatin1String("none"));
+    lineColor = qElement.attribute(QLatin1String("linecolor"), lineColor);
+    if (lineColor != QLatin1String("none")) {
         m_lineColor = QColor(lineColor);
         m_usesDiagramLineColor = false;
     } else if (m_baseType != WidgetBase::wt_Box && m_scene != NULL) {
         m_lineColor = m_scene->lineColor();
         m_usesDiagramLineColor = true;
     }
-    QString lineWidth = qElement.attribute("linewidth", "none");
-    if (lineWidth != "none") {
+    QString lineWidth = qElement.attribute(QLatin1String("linewidth"), QLatin1String("none"));
+    if (lineWidth != QLatin1String("none")) {
         m_lineWidth = lineWidth.toInt();
         m_usesDiagramLineWidth = false;
     } else if (m_scene) {
         m_lineWidth = m_scene->lineWidth();
         m_usesDiagramLineWidth = true;
     }
-    QString textColor = qElement.attribute("textcolor", "none");
-    if (textColor != "none") {
+    QString textColor = qElement.attribute(QLatin1String("textcolor"), QLatin1String("none"));
+    if (textColor != QLatin1String("none")) {
         m_textColor = QColor(textColor);
         m_usesDiagramTextColor = false;
     } else if (m_scene) {
         m_textColor = m_scene->textColor();
         m_usesDiagramTextColor = true;
     }
-    QString usefillcolor = qElement.attribute("usefillcolor", "1");
+    QString usefillcolor = qElement.attribute(QLatin1String("usefillcolor"), QLatin1String("1"));
     m_useFillColor = (bool)usefillcolor.toInt();
     /*
       For the next three *color attributes, there was a mixup of american and english spelling for "color".
       So first we need to keep backward compatibility and try to retrieve the *colour attribute.
       Next we overwrite this value if we find a *color, otherwise the former *colour is kept.
     */
-    QString fillColor = qElement.attribute("fillcolour", "none");
-    fillColor = qElement.attribute("fillcolor", fillColor);
-    if (fillColor != "none") {
+    QString fillColor = qElement.attribute(QLatin1String("fillcolour"), QLatin1String("none"));
+    fillColor = qElement.attribute(QLatin1String("fillcolor"), fillColor);
+    if (fillColor != QLatin1String("none")) {
         m_fillColor = QColor(fillColor);
     }
 
-    QString usesDiagramFillColor = qElement.attribute("usesdiagramfillcolour", "1");
-    usesDiagramFillColor = qElement.attribute("usesdiagramfillcolor", usesDiagramFillColor);
+    QString usesDiagramFillColor = qElement.attribute(QLatin1String("usesdiagramfillcolour"), QLatin1String("1"));
+    usesDiagramFillColor = qElement.attribute(QLatin1String("usesdiagramfillcolor"), usesDiagramFillColor);
     m_usesDiagramFillColor = (bool)usesDiagramFillColor.toInt();
 
-    QString usesDiagramUseFillColor = qElement.attribute("usesdiagramusefillcolour", "1");
-    usesDiagramUseFillColor = qElement.attribute("usesdiagramusefillcolor", usesDiagramUseFillColor);
+    QString usesDiagramUseFillColor = qElement.attribute(QLatin1String("usesdiagramusefillcolour"), QLatin1String("1"));
+    usesDiagramUseFillColor = qElement.attribute(QLatin1String("usesdiagramusefillcolor"), usesDiagramUseFillColor);
     m_usesDiagramUseFillColor = (bool)usesDiagramUseFillColor.toInt();
 
-    QString font = qElement.attribute("font", "");
+    QString font = qElement.attribute(QLatin1String("font"));
     if (!font.isEmpty()) {
         QFont newFont;
         newFont.fromString(font);
@@ -645,12 +643,44 @@ QRectF WidgetBase::boundingRect() const
     return m_rect.adjusted(-halfWidth, -halfWidth, halfWidth, halfWidth);
 }
 
+/**
+ * Test if point is inside the bounding rectangle of the widget.
+ * Inheriting classes may reimplement this to test possible child widgets.
+ *
+ * @param p Point to be checked.
+ *
+ * @return 'this' if the given point is in the boundaries of the widget;
+ *         else NULL.
+ */
+UMLWidget* WidgetBase::onWidget(const QPointF &p)
+{
+    UMLWidget *uw = dynamic_cast<UMLWidget*>(this);
+    if (uw == NULL)
+        return NULL;
+    const qreal w = m_rect.width();
+    const qreal h = m_rect.height();
+    const qreal left = x();  // don't use m_rect.x() for this, it is always 0
+    const qreal right = left + w;
+    const qreal top = y();   // don't use m_rect.y() for this, it is always 0
+    const qreal bottom = top + h;
+    // uDebug() << "p=(" << p.x() << "," << p.y()
+    //          << "), x=" << left << ", y=" << top << ", w=" << w << ", h=" << h
+    //          << "; right=" << right << ", bottom=" << bottom;
+    if (p.x() < left || p.x() > right ||
+            p.y() < top || p.y() > bottom) { // Qt coord.sys. origin in top left corner
+        // uDebug() << "returning NULL";
+        return NULL;
+    }
+    // uDebug() << "returning this";
+    return uw;
+}
+
 /**
  * Draws the UMLWidget on the given paint device
  *
- * @param p The painter for the drawing device
- * @param offsetX x position to start the drawing.
- * @param offsetY y position to start the drawing.
+ * @param painter The painter for the drawing device
+ * @param option  Painting related options
+ * @param widget  Background widget on which to paint (optional)
  *
  */
 void WidgetBase::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -702,7 +732,7 @@ void WidgetBase::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
     ListPopupMenu *parentMenu = ListPopupMenu::menuFromAction(triggered);
 
     if (!parentMenu) {
-        uError() << "Action's data field does not contain ListPopupMenu pointer";
+        uDebug() << "Action's data field does not contain ListPopupMenu pointer";
         return;
     }
 
@@ -745,6 +775,7 @@ void WidgetBase::slotMenuSelection(QAction *trigger)
             wt == WidgetBase::wt_Datatype  || wt == WidgetBase::wt_Node      ||
             wt == WidgetBase::wt_Component || wt == WidgetBase::wt_Artifact  ||
             wt == WidgetBase::wt_Enum      || wt == WidgetBase::wt_Entity    ||
+            wt == WidgetBase::wt_Port      ||
             (wt == WidgetBase::wt_Class && umlScene()->type() == Uml::DiagramType::Class)) {
 
             showPropertiesDialog();
